@@ -101,7 +101,7 @@ def download_binaries_if_not_found(binary_dir):
             binary_dir)
     )
     if yn.lower() in ["y", "yes"]:
-        os.system("git clone {} {}".format(UNITY_EXE_REPOSITORY, UNITY_EXE_DIR))
+        os.system("git lfs clone {} {}".format(UNITY_EXE_REPOSITORY, UNITY_EXE_DIR))
     else:
         raise ValueError("Simulator binaries not downloaded, aborting.")
     if not os.path.isdir(binary_dir):
